@@ -10,7 +10,4 @@ from permission.utils.logics import add_permission_logic
 from permission.utils.logics import remove_permission_logic
 
 # autodiscover
-from permission.conf import settings
 from permission.utils.autodiscover import autodiscover
-if settings.PERMISSION_AUTODISCOVER_ENABLE:
-    autodiscover()
