@@ -4,6 +4,7 @@
 __author__ = 'Alisue <lambdalisue@hashnote.net>'
 from django.test import TestCase
 from permission.tests.utils import create_user
+from permission.tests.utils import create_anonymous
 from permission.tests.utils import create_group
 from permission.tests.utils import create_article
 from permission.tests.compatibility import MagicMock
@@ -23,6 +24,7 @@ class PermissionLogicsAuthorPermissionLogicTestCase(TestCase):
         self.user1 = create_user('john')
         self.user2 = create_user('tony')
         self.user3 = create_user('peter')
+        self.anonymous = create_anonymous()
         self.group1 = create_group('admin', self.user1)
         self.group2 = create_group('staff', self.user2)
         self.perm1 = 'permission.add_article'
@@ -134,6 +136,39 @@ class PermissionLogicsAuthorPermissionLogicTestCase(TestCase):
         self.assertFalse(
                 permission_logic.has_perm(self.user3, self.perm3, self.article))
 
+    def test_has_perm_add_without_obj_with_anonymous(self):
+        permission_logic = GroupInPermissionLogic('admin')
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(permission_logic.has_perm(self.anonymous, self.perm1))
+
+    def test_has_perm_change_without_obj_with_anonymous(self):
+        permission_logic = GroupInPermissionLogic('admin')
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(permission_logic.has_perm(self.anonymous, self.perm2))
+
+    def test_has_perm_delete_without_obj_with_anonymous(self):
+        permission_logic = GroupInPermissionLogic('admin')
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(permission_logic.has_perm(self.anonymous, self.perm3))
+
+    def test_has_perm_add_with_obj_with_anonymous(self):
+        permission_logic = GroupInPermissionLogic('admin')
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(
+            permission_logic.has_perm(self.anonymous, self.perm1, self.article))
+
+    def test_has_perm_change_with_obj_with_anonymous(self):
+        permission_logic = GroupInPermissionLogic('admin')
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(
+            permission_logic.has_perm(self.anonymous, self.perm2, self.article))
+
+    def test_has_perm_delete_with_obj_with_anonymous(self):
+        permission_logic = GroupInPermissionLogic('admin')
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(
+            permission_logic.has_perm(self.anonymous, self.perm3, self.article))
+
     def test_has_perm_add_without_obj_with_two_groups(self):
         permission_logic = GroupInPermissionLogic(['admin', 'staff'])
         add_permission_logic(self.article.__class__, permission_logic)
