@@ -4,6 +4,7 @@
 __author__ = 'Alisue <lambdalisue@hashnote.net>'
 from django.test import TestCase
 from permission.tests.utils import create_user
+from permission.tests.utils import create_anonymous
 from permission.tests.utils import create_article
 from permission.tests.compatibility import override_settings
 from permission.logics import StaffPermissionLogic
@@ -20,6 +21,7 @@ class PermissionLogicsStaffPermissionLogicTestCase(TestCase):
     def setUp(self):
         self.user1 = create_user('john', is_staff=True)
         self.user2 = create_user('tony')
+        self.anonymous = create_anonymous()
         self.perm1 = 'permission.add_article'
         self.perm2 = 'permission.change_article'
         self.perm3 = 'permission.delete_article'
@@ -101,6 +103,39 @@ class PermissionLogicsStaffPermissionLogicTestCase(TestCase):
         self.assertFalse(
                 permission_logic.has_perm(self.user2, self.perm3, self.article))
 
+    def test_has_perm_add_without_obj_with_anonymous(self):
+        permission_logic = StaffPermissionLogic()
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(permission_logic.has_perm(self.anonymous, self.perm1))
+
+    def test_has_perm_change_without_obj_with_anonymous(self):
+        permission_logic = StaffPermissionLogic()
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(permission_logic.has_perm(self.anonymous, self.perm2))
+
+    def test_has_perm_delete_without_obj_with_anonymous(self):
+        permission_logic = StaffPermissionLogic()
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(permission_logic.has_perm(self.anonymous, self.perm3))
+
+    def test_has_perm_add_with_obj_with_anonymous(self):
+        permission_logic = StaffPermissionLogic()
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(
+            permission_logic.has_perm(self.anonymous, self.perm1, self.article))
+
+    def test_has_perm_change_with_obj_with_anonymous(self):
+        permission_logic = StaffPermissionLogic()
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(
+            permission_logic.has_perm(self.anonymous, self.perm2, self.article))
+
+    def test_has_perm_delete_with_obj_with_anonymous(self):
+        permission_logic = StaffPermissionLogic()
+        add_permission_logic(self.article.__class__, permission_logic)
+        self.assertFalse(
+            permission_logic.has_perm(self.anonymous, self.perm3, self.article))
+
     def test_has_perm_add_without_obj_without_any(self):
         permission_logic = StaffPermissionLogic(any_permission=False)
         add_permission_logic(self.article.__class__, permission_logic)
